#
# spec file for package redis
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _data_dir       %{_localstatedir}/lib/%{name}
%define _log_dir        %{_localstatedir}/log/%{name}
%define _conf_dir       %{_sysconfdir}/%{name}
%if 0%{?suse_version} > 1230
%bcond_without systemd
%else
%bcond_with    systemd
%endif
Name:           redis
Version:        3.2.9
Release:        0
Summary:        Persistent key-value database
License:        BSD-3-Clause
Group:          Productivity/Databases/Servers
Url:            http://redis.io/
Source:         http://download.redis.io/releases/redis-%{version}.tar.gz
Source1:        %{name}.logrotate
Source2:        redis.target
Source3:        redis@.service
Source4:        redis.tmpfiles.d
Source5:        README.SUSE
Source6:        %{name}.sysctl
# PATCH-FIX-OPENSUSE -- openSUSE-style init script
Patch0:         %{name}-initscript.patch
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/openSUSE:Packaging_Patches_guidelines
Patch1:         %{name}-conf.patch
Patch2:         redis-enable-bactrace-on-x86-and-ia64-only.patch
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  tcl
Requires:       logrotate
Requires:       sudo
Requires(pre):  shadow
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         %insserv_prereq %fillup_prereq
%endif

%description
Redis is an advanced key-value store. It is similar to memcached but the dataset
is not volatile, and values can be strings, exactly like in memcached,
but also lists, sets, and ordered sets. All this data types can be manipulated
with atomic operations to push/pop elements, add/remove elements, perform server
side union, intersection, difference between sets, and so forth. Redis supports
different kind of sorting abilities.

%prep
%setup -q
%patch0
%patch1
%patch2

%build
make %{?_smp_mflags} CFLAGS="%{optflags}" V=1

%install
install -m 0750 -d \
  %{buildroot}%{_log_dir} \
  %{buildroot}%{_data_dir} \
  %{buildroot}%{_conf_dir} \
  %{buildroot}%{_log_dir}/default \
  %{buildroot}%{_data_dir}/default

install -Dpm 0755 src/redis-benchmark  %{buildroot}%{_bindir}/redis-benchmark
install -Dpm 0755 src/redis-cli        %{buildroot}%{_bindir}/redis-cli
install -Dpm 0755 src/redis-check-aof  %{buildroot}%{_bindir}/redis-check-aof
install -Dpm 0755 src/redis-check-rdb  %{buildroot}%{_bindir}/redis-check-rdb
install -Dpm 0755 src/redis-trib.rb    %{buildroot}%{_bindir}/redis-trib.rb
install -Dpm 0755 src/redis-server     %{buildroot}%{_sbindir}/redis-server
ln -sfv            redis-server         %{buildroot}%{_sbindir}/redis-sentinel

%if %{with systemd}
perl -p -i -e 's|daemonize yes|daemonize no|g' redis.conf
%endif
install -D -m 0640 redis.conf           %{buildroot}%{_conf_dir}/default.conf.example
install -D -m 0640 sentinel.conf        %{buildroot}%{_conf_dir}/sentinel.conf.example

# some sysctl stuff
install -D -m 0644 %{S:6}               %{buildroot}%{_sysconfdir}/sysctl.d/00-redis.conf

#
# init
#
%if %{with systemd}
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/redis.target
install -D -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/redis@.service
install -D -m 0644 %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
ln -s -f %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
cp %{SOURCE5} README.SUSE
%else
install -D -m 0755 utils/redis_init_script %{buildroot}%{_sysconfdir}/init.d/redis
ln -s %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif

#
# logrotate
#
install -D -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%check
%ifnarch ppc ppc64
cat <<EOF
---------------------------------------------------
The test suite often fails to start a server, with
'child process exited abnormally' -- sometimes it works.
---------------------------------------------------
EOF
make %{?_smp_mflags} test && true
%endif

%pre
getent group %{name} >/dev/null || %{_sbindir}/groupadd -r %{name} || :
getent passwd %{name} >/dev/null || \
	%{_sbindir}/useradd -g %{name} -s /bin/false -r \
	-c "User for Redis key-value store" -d %{_data_dir} %{name} || :
%if %{with systemd}
%service_add_pre %{name}.target
%endif

%post
%if %{with systemd}
systemd-tmpfiles --create %{_prefix}/lib/tmpfiles.d/%{name}.conf || true
%service_add_post %{name}.target
echo "See %{_docdir}/redis/README.SUSE to continue"
%else
echo "To start the database server, create your configuration"
echo "starting from %{_sysconfdir}/redis/default.conf.example, place it"
echo "in %{_sysconfdir}/redis and do: "
echo " sudo rcredis start; sudo chkconfig redis on"
%endif

%preun
%if %{with systemd}
%service_del_preun %{name}.target
%else
%stop_on_removal %{name}
%endif

%postun
%if %{with systemd}
%service_del_postun %{name}.target
%else
%restart_on_update %{name}
%insserv_cleanup
%endif

%files
%defattr(-,root,root,-)
%doc 00-RELEASENOTES BUGS CONTRIBUTING COPYING README.md
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysctl.d/00-redis.conf
%{_bindir}/redis-*
%{_sbindir}/redis-*
%{_sbindir}/rc%{name}
%if %{with systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.target
%doc README.SUSE
%else
%config(noreplace) %{_sysconfdir}/init.d/%{name}
%endif
%config(noreplace) %attr(-, root, %{name}) %{_conf_dir}/
#
%dir %attr(0750, %{name}, %{name}) %{_data_dir}
%dir %attr(0750, %{name}, %{name}) %{_data_dir}/default
%dir %attr(0750, %{name}, %{name}) %{_log_dir}

%changelog
